@@ -235,6 +235,52 @@ class TeoClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateL4Proxy(self, request):
+        """用于创建四层代理实例。
+
+        :param request: Request instance for CreateL4Proxy.
+        :type request: :class:`tencentcloud.teo.v20220901.models.CreateL4ProxyRequest`
+        :rtype: :class:`tencentcloud.teo.v20220901.models.CreateL4ProxyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateL4Proxy", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateL4ProxyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CreateL4ProxyRules(self, request):
+        """用于创建四层代理实例规则，支持单条或者批量创建。
+
+        :param request: Request instance for CreateL4ProxyRules.
+        :type request: :class:`tencentcloud.teo.v20220901.models.CreateL4ProxyRulesRequest`
+        :rtype: :class:`tencentcloud.teo.v20220901.models.CreateL4ProxyRulesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateL4ProxyRules", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateL4ProxyRulesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateOriginGroup(self, request):
         """创建源站组，以源站组的方式管理业务源站。此处配置的源站组可于**添加加速域名**和**四层代理**等功能中引用。
 
@@ -515,6 +561,52 @@ class TeoClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteL4Proxy(self, request):
+        """用于删除四层代理实例。
+
+        :param request: Request instance for DeleteL4Proxy.
+        :type request: :class:`tencentcloud.teo.v20220901.models.DeleteL4ProxyRequest`
+        :rtype: :class:`tencentcloud.teo.v20220901.models.DeleteL4ProxyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteL4Proxy", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteL4ProxyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DeleteL4ProxyRules(self, request):
+        """用于删除四层代理转发规则，支持单条或者批量操作。
+
+        :param request: Request instance for DeleteL4ProxyRules.
+        :type request: :class:`tencentcloud.teo.v20220901.models.DeleteL4ProxyRulesRequest`
+        :rtype: :class:`tencentcloud.teo.v20220901.models.DeleteL4ProxyRulesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteL4ProxyRules", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteL4ProxyRulesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteOriginGroup(self, request):
         """删除源站组，若源站组仍然被服务（例如：四层代理，域名服务，负载均衡，规则引起）引用，将不允许删除。
 
@@ -745,6 +837,29 @@ class TeoClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeBillingData(self, request):
+        """通过本接口查询计费数据。
+
+        :param request: Request instance for DescribeBillingData.
+        :type request: :class:`tencentcloud.teo.v20220901.models.DescribeBillingDataRequest`
+        :rtype: :class:`tencentcloud.teo.v20220901.models.DescribeBillingDataResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeBillingData", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeBillingDataResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeConfigGroupVersionDetail(self, request):
         """在版本管理模式下，用于获取版本的详细信息，包括版本 ID、描述、状态、创建时间、所属配置组信息以及版本配置文件的内容。版本管理功能内测中，当前仅白名单开放。
 
@@ -975,6 +1090,29 @@ class TeoClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeIPRegion(self, request):
+        """该接口可用于查询 IP 是否为 EdgeOne IP。
+
+        :param request: Request instance for DescribeIPRegion.
+        :type request: :class:`tencentcloud.teo.v20220901.models.DescribeIPRegionRequest`
+        :rtype: :class:`tencentcloud.teo.v20220901.models.DescribeIPRegionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeIPRegion", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeIPRegionResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeIdentifications(self, request):
         """查询站点的验证信息。
 
@@ -998,6 +1136,52 @@ class TeoClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeL4Proxy(self, request):
+        """用于查询四层代理实例列表。
+
+        :param request: Request instance for DescribeL4Proxy.
+        :type request: :class:`tencentcloud.teo.v20220901.models.DescribeL4ProxyRequest`
+        :rtype: :class:`tencentcloud.teo.v20220901.models.DescribeL4ProxyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeL4Proxy", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeL4ProxyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeL4ProxyRules(self, request):
+        """查询四层代理实例下的规则列表。
+
+        :param request: Request instance for DescribeL4ProxyRules.
+        :type request: :class:`tencentcloud.teo.v20220901.models.DescribeL4ProxyRulesRequest`
+        :rtype: :class:`tencentcloud.teo.v20220901.models.DescribeL4ProxyRulesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeL4ProxyRules", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeL4ProxyRulesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeOriginGroup(self, request):
         """获取源站组列表
 
@@ -1621,6 +1805,98 @@ class TeoClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyL4Proxy(self, request):
+        """用于修改四层代理实例的配置。
+
+        :param request: Request instance for ModifyL4Proxy.
+        :type request: :class:`tencentcloud.teo.v20220901.models.ModifyL4ProxyRequest`
+        :rtype: :class:`tencentcloud.teo.v20220901.models.ModifyL4ProxyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyL4Proxy", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyL4ProxyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyL4ProxyRules(self, request):
+        """用于修改四层代理转发规则，支持单条或者批量修改。
+
+        :param request: Request instance for ModifyL4ProxyRules.
+        :type request: :class:`tencentcloud.teo.v20220901.models.ModifyL4ProxyRulesRequest`
+        :rtype: :class:`tencentcloud.teo.v20220901.models.ModifyL4ProxyRulesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyL4ProxyRules", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyL4ProxyRulesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyL4ProxyRulesStatus(self, request):
+        """用于启用/停用四层代理转发规则状态，支持单条或者批量操作。
+
+        :param request: Request instance for ModifyL4ProxyRulesStatus.
+        :type request: :class:`tencentcloud.teo.v20220901.models.ModifyL4ProxyRulesStatusRequest`
+        :rtype: :class:`tencentcloud.teo.v20220901.models.ModifyL4ProxyRulesStatusResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyL4ProxyRulesStatus", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyL4ProxyRulesStatusResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyL4ProxyStatus(self, request):
+        """用于启用/停用四层代理实例。
+
+        :param request: Request instance for ModifyL4ProxyStatus.
+        :type request: :class:`tencentcloud.teo.v20220901.models.ModifyL4ProxyStatusRequest`
+        :rtype: :class:`tencentcloud.teo.v20220901.models.ModifyL4ProxyStatusResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyL4ProxyStatus", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyL4ProxyStatusResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyOriginGroup(self, request):
         """修改源站组配置，新提交的源站记录将会覆盖原有源站组中的源站记录。
 
